==> zio-aws-comprehend_3-5.17.116.1-sources.jar: zio/aws/comprehend/model/StopEventsDetectionJobResponse.scala <==
package zio.aws.comprehend.model
import zio.aws.comprehend.model.primitives.JobId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class StopEventsDetectionJobResponse(
    jobId: Option[JobId] = None,
    jobStatus: Option[zio.aws.comprehend.model.JobStatus] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse = {
    import StopEventsDetectionJobResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .optionallyWith(jobStatus.map(value => value.unwrap))(_.jobStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.StopEventsDetectionJobResponse.ReadOnly =
    zio.aws.comprehend.model.StopEventsDetectionJobResponse
      .wrap(buildAwsValue())
}
object StopEventsDetectionJobResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.StopEventsDetectionJobResponse =
      zio.aws.comprehend.model.StopEventsDetectionJobResponse(
        jobId.map(value => value),
        jobStatus.map(value => value)
      )
    def jobId: Option[JobId]
    def jobStatus: Option[zio.aws.comprehend.model.JobStatus]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
    def getJobStatus: ZIO[Any, AwsError, zio.aws.comprehend.model.JobStatus] =
      AwsError.unwrapOptionField("jobStatus", jobStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse
  ) extends zio.aws.comprehend.model.StopEventsDetectionJobResponse.ReadOnly {
    override val jobId: Option[JobId] = scala
      .Option(impl.jobId())
      .map(value => zio.aws.comprehend.model.primitives.JobId(value))
    override val jobStatus: Option[zio.aws.comprehend.model.JobStatus] = scala
      .Option(impl.jobStatus())
      .map(value => zio.aws.comprehend.model.JobStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse
  ): zio.aws.comprehend.model.StopEventsDetectionJobResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-comprehend_3-5.17.201.2-sources.jar: zio/aws/comprehend/model/StopEventsDetectionJobResponse.scala <==
package zio.aws.comprehend.model
import zio.aws.comprehend.model.primitives.JobId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class StopEventsDetectionJobResponse(
    jobId: Optional[JobId] = Optional.Absent,
    jobStatus: Optional[zio.aws.comprehend.model.JobStatus] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse = {
    import StopEventsDetectionJobResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse
      .builder()
      .optionallyWith(
        jobId.map(value => JobId.unwrap(value): java.lang.String)
      )(_.jobId)
      .optionallyWith(jobStatus.map(value => value.unwrap))(_.jobStatus)
      .build()
  }
  def asReadOnly
      : zio.aws.comprehend.model.StopEventsDetectionJobResponse.ReadOnly =
    zio.aws.comprehend.model.StopEventsDetectionJobResponse
      .wrap(buildAwsValue())
}
object StopEventsDetectionJobResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.comprehend.model.StopEventsDetectionJobResponse =
      zio.aws.comprehend.model.StopEventsDetectionJobResponse(
        jobId.map(value => value),
        jobStatus.map(value => value)
      )
    def jobId: Optional[JobId]
    def jobStatus: Optional[zio.aws.comprehend.model.JobStatus]
    def getJobId: ZIO[Any, AwsError, JobId] =
      AwsError.unwrapOptionField("jobId", jobId)
    def getJobStatus: ZIO[Any, AwsError, zio.aws.comprehend.model.JobStatus] =
      AwsError.unwrapOptionField("jobStatus", jobStatus)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse
  ) extends zio.aws.comprehend.model.StopEventsDetectionJobResponse.ReadOnly {
    override val jobId: Optional[JobId] = zio.aws.core.internal
      .optionalFromNullable(impl.jobId())
      .map(value => zio.aws.comprehend.model.primitives.JobId(value))
    override val jobStatus: Optional[zio.aws.comprehend.model.JobStatus] =
      zio.aws.core.internal
        .optionalFromNullable(impl.jobStatus())
        .map(value => zio.aws.comprehend.model.JobStatus.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.comprehend.model.StopEventsDetectionJobResponse
  ): zio.aws.comprehend.model.StopEventsDetectionJobResponse.ReadOnly =
    new Wrapper(impl)
}
